complete -c daktilo -s p -l preset -d 'Sets the name of the sound preset to use' -r
complete -c daktilo -s d -l device -d 'Sets the device for playback' -r
complete -c daktilo -s c -l config -d 'Sets the configuration file' -r -F
complete -c daktilo -l variate-volume -d 'Variate volume +/- in percent' -r
complete -c daktilo -l variate-tempo -d 'Variate tempo +/- in percent' -r
complete -c daktilo -s v -l verbose -d 'Enables verbose logging'
complete -c daktilo -s l -l list-presets -d 'Lists the available presets'
complete -c daktilo -l list-devices -d 'Lists the available output devices'
complete -c daktilo -s i -l init -d 'Writes the default configuration file'
complete -c daktilo -l no-surprises -d 'Disables the easter eggs'
complete -c daktilo -s h -l help -d 'Print help (see more with \'--help\')'
complete -c daktilo -s V -l version -d 'Print version'
